@@ -1,6 +1,6 @@
 --[[
 Copyright (c) 2016, Andrew Lewis <nerf@judo.za.org>
-Copyright (c) 2016, Vsevolod Stakhov <vsevolod@highsecure.ru>
+Copyright (c) 2022, Vsevolod Stakhov <vsevolod@rspamd.com>
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
@@ -19,6 +19,7 @@ local lua_util = require "lua_util"
 local rspamd_logger = require "rspamd_logger"
 local dkim_sign_tools = require "lua_dkim_tools"
 local lua_redis = require "lua_redis"
+local lua_mime = require "lua_mime"
 
 if confighelp then
   return
@@ -32,7 +33,9 @@ local settings = {
   allow_hdrfrom_multiple = false,
   allow_username_mismatch = false,
   allow_pubkey_mismatch = true,
-  auth_only = true,
+  sign_authenticated = true,
+  allowed_ids = nil,
+  forbidden_ids = nil,
   check_pubkey = false,
   domain = {},
   path = string.format('%s/%s/%s', rspamd_paths['DBDIR'], 'dkim', '$domain.$selector.key'),
@@ -44,13 +47,31 @@ local settings = {
   use_esld = true,
   use_redis = false,
   key_prefix = 'dkim_keys', -- default hash name
+  use_milter_headers = false, -- use milter headers instead of `dkim_signature`
 }
 
 local N = 'dkim_signing'
 local redis_params
 local sign_func = rspamd_plugins.dkim.sign
 
+local function insert_sign_results(task, ret, hdr, dkim_params)
+  if settings.use_milter_headers then
+    lua_mime.modify_headers(task, {
+      add = {
+        ['DKIM-Signature'] = {order = 1, value = hdr},
+      }
+    })
+  end
+  if ret then
+    task:insert_result(settings.symbol, 1.0, string.format('%s:s=%s',
+        dkim_params.domain, dkim_params.selector))
+  end
+end
+
 local function do_sign(task, p)
+  if settings.use_milter_headers then
+    p.no_cache = true -- Disable caching in rspamd_mempool
+  end
   if settings.check_pubkey then
     local resolve_name = p.selector .. "._domainkey." .. p.domain
     task:get_resolver():resolve_txt({
@@ -61,26 +82,22 @@ local function do_sign(task, p)
           p.pubkey = results[1]
           p.strict_pubkey_check = not settings.allow_pubkey_mismatch
         elseif not settings.allow_pubkey_mismatch then
-          rspamd_logger.errx('public key for domain %s/%s is not found: %s, skip signing',
+          rspamd_logger.infox(task, 'public key for domain %s/%s is not found: %s, skip signing',
               p.domain, p.selector, err)
           return
         else
-          rspamd_logger.infox('public key for domain %s/%s is not found: %s',
+          rspamd_logger.infox(task, 'public key for domain %s/%s is not found: %s',
               p.domain, p.selector, err)
         end
 
-        local sret, _ = sign_func(task, p)
-        if sret then
-          task:insert_result(settings.symbol, 1.0)
-        end
+        local sret, hdr = sign_func(task, p)
+        insert_sign_results(task, sret, hdr, p)
       end,
       forced = true
     })
   else
-    local sret, _ = sign_func(task, p)
-    if sret then
-      task:insert_result(settings.symbol, 1.0)
-    end
+    local sret, hdr = sign_func(task, p)
+    insert_sign_results(task, sret, hdr, p)
   end
 end
 
@@ -147,13 +164,21 @@ if settings.use_redis then
   settings.redis_params = redis_params
 end
 
-
-rspamd_config:register_symbol({
+local sym_reg_tbl = {
   name = settings['symbol'],
   callback = dkim_signing_cb,
   groups = {"policies", "dkim"},
+  flags = 'ignore_passthrough',
   score = 0.0,
-})
+}
 
+if type(settings.allowed_ids) == 'table' then
+  sym_reg_tbl.allowed_ids = settings.allowed_ids
+end
+if type(settings.forbidden_ids) == 'table' then
+  sym_reg_tbl.forbidden_ids = settings.forbidden_ids
+end
+
+rspamd_config:register_symbol(sym_reg_tbl)
 -- Add dependency on DKIM checks
 rspamd_config:register_dependency(settings['symbol'], 'DKIM_CHECK')
